Padding

Enum Padding 

#[non_exhaustive]
pub enum Padding { Explicit(Vec<i64>), Same, Valid, }
Convolution / pooling padding specification.

Upstream NIR accepts integer extents or the string modes "same" / "valid".

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Explicit(Vec<i64>)

Explicit per-axis padding extents (length 1 for 1d, 2 for 2d, …).



Same

Pad so that spatial output size matches input ("same").



Valid

No padding ("valid").

Implementations

Source

impl Padding

pub fn single(value: i64) -> Self

Single-axis explicit padding.

pub fn pair(h: i64, w: i64) -> Self

Two-axis explicit padding (h, w).