#[non_exhaustive]pub enum Padding {
Explicit(Vec<i64>),
Same,
Valid,
}Expand description
Convolution / pooling padding specification.
Upstream NIR accepts integer extents or the string modes "same" / "valid".
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Explicit(Vec<i64>)
Explicit per-axis padding extents (length 1 for 1d, 2 for 2d, …).
Same
Pad so that spatial output size matches input ("same").
Valid
No padding ("valid").
Implementations